<?php
session_start();
// 登录验证
if (!isset($_SESSION['user_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['error' => '未登录或会话已过期']);
    exit;
}

// 包含数据库连接
require_once '../config.php';

// 设置响应头
header('Content-Type: application/json');

// 检查参数
if (isset($_GET['receivable_id'])) {
    // 获取指定应收账款的付款历史
    $receivable_id = (int)$_GET['receivable_id'];

    try {
        $stmt = $pdo->prepare("
            SELECT 
                id, 
                amount, 
                payment_date, 
                payment_method, 
                reference_number, 
                notes, 
                created_at
            FROM 
                payments_received
            WHERE 
                receivable_id = :receivable_id
            ORDER BY 
                payment_date DESC, created_at DESC
        ");

        $stmt->execute([':receivable_id' => $receivable_id]);
        $payments = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode($payments);
    } catch (PDOException $e) {
        echo json_encode(['error' => '查询数据时出错: ' . $e->getMessage()]);
    }
} else if (isset($_GET['payable_id'])) {
    // 获取指定应付账款的付款历史
    $payable_id = (int)$_GET['payable_id'];

    try {
        $stmt = $pdo->prepare("
            SELECT 
                id, 
                amount, 
                payment_date, 
                payment_method, 
                reference_number, 
                notes, 
                created_at
            FROM 
                payments_made
            WHERE 
                payable_id = :payable_id
            ORDER BY 
                payment_date DESC, created_at DESC
        ");

        $stmt->execute([':payable_id' => $payable_id]);
        $payments = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode($payments);
    } catch (PDOException $e) {
        echo json_encode(['error' => '查询数据时出错: ' . $e->getMessage()]);
    }
} else {
    // 没有提供有效的参数
    echo json_encode(['error' => '缺少必要的参数']);
}
