<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';

// 检查shipments表是否存在
try {
    $stmt = $pdo->query("SHOW TABLES LIKE 'shipments'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，查看SQL文件中的定义
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        // 提取shipments表的创建SQL
        if (preg_match('/CREATE TABLE\s+`shipments`\s*\((.*?)\)\s*ENGINE\s*=/s', $sql_file, $matches)) {
            $create_shipments_sql = "CREATE TABLE `shipments` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '发货记录表'";
            $pdo->exec($create_shipments_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`shipments`(.*?);\s*--/s', $sql_file, $insert_matches)) {
                $insert_shipments_sql = "INSERT INTO `shipments`" . $insert_matches[1];
                $pdo->exec($insert_shipments_sql);
            }
        } else {
            // 如果在SQL文件中找不到定义，则使用以下备用定义
            $pdo->exec("
                CREATE TABLE `shipments` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '发货ID',
                  `shipment_number` VARCHAR(50) NOT NULL COMMENT '发货单号',
                  `sales_order_id` INT UNSIGNED NOT NULL COMMENT '关联销售订单ID',
                  `carrier_id` INT UNSIGNED DEFAULT NULL COMMENT '承运商ID',
                  `tracking_number` VARCHAR(100) DEFAULT NULL COMMENT '物流单号',
                  `shipment_date` DATETIME NOT NULL COMMENT '发货日期时间',
                  `estimated_delivery_date` DATE DEFAULT NULL COMMENT '预计送达日期',
                  `actual_delivery_date` DATETIME DEFAULT NULL COMMENT '实际送达日期时间',
                  `shipping_cost` DECIMAL(10, 2) DEFAULT NULL COMMENT '物流费用',
                  `status` ENUM(
                    'pending',
                    'ready_to_ship',
                    'shipped',
                    'in_transit',
                    'delivered',
                    'failed',
                    'cancelled'
                  ) NOT NULL DEFAULT 'pending' COMMENT '发货状态',
                  `notes` TEXT DEFAULT NULL COMMENT '备注',
                  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                  PRIMARY KEY (`id`),
                  UNIQUE KEY `uk_shipment_number` (`shipment_number`),
                  KEY `idx_ship_order` (`sales_order_id`),
                  KEY `idx_ship_carrier` (`carrier_id`),
                  KEY `idx_ship_status` (`status`),
                  KEY `idx_ship_date` (`shipment_date`)
                ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '发货记录表'
            ");

            // 插入示例数据
            $pdo->exec("
                INSERT INTO
                  `shipments` (
                    `shipment_number`,
                    `sales_order_id`,
                    `carrier_id`,
                    `tracking_number`,
                    `shipment_date`,
                    `estimated_delivery_date`,
                    `shipping_cost`,
                    `status`
                  )
                VALUES
                  (
                    'SHP20240725001',
                    1,
                    2,
                    'DB123456789',
                    '2024-07-25 16:00:00',
                    '2024-07-28',
                    150.00,
                    'shipped'
                  ),
                  (
                    'SHP20240726001',
                    2,
                    1,
                    'SF987654321',
                    '2024-07-26 10:30:00',
                    '2024-07-27',
                    15.50,
                    'in_transit'
                  ),
                  (
                    'SHP20240728001',
                    3,
                    4,
                    'LLZ998877',
                    '2024-07-28 09:00:00',
                    '2024-08-01',
                    800.00,
                    'ready_to_ship'
                  ),
                  (
                    'SHP20240729001',
                    1,
                    2,
                    'DB112233445',
                    '2024-07-29 11:00:00',
                    '2024-08-01',
                    50.00,
                    'pending'
                  )
            ");
        }
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败：" . $e->getMessage();
}

// 处理添加发货单请求
if (isset($_POST['add_shipment'])) {
    $sales_order_id = (int)$_POST['sales_order_id'];
    $carrier_id = !empty($_POST['carrier_id']) ? (int)$_POST['carrier_id'] : null;
    $shipment_date = $_POST['shipment_date'];
    $estimated_delivery_date = !empty($_POST['estimated_delivery_date']) ? $_POST['estimated_delivery_date'] : null;
    $shipping_cost = !empty($_POST['shipping_cost']) ? $_POST['shipping_cost'] : null;
    $status = $_POST['status'];
    $notes = trim($_POST['notes']);

    try {
        // 检查销售订单是否存在
        $stmt = $pdo->prepare("SELECT id, order_number FROM sales_orders WHERE id = ?");
        $stmt->execute([$sales_order_id]);
        $order = $stmt->fetch();

        if (!$order) {
            throw new Exception("销售订单不存在");
        }

        // 生成发货单号
        $shipment_number = 'SHP' . date('Ymd') . sprintf('%03d', rand(1, 999));

        // 确保发货单号唯一
        $stmt = $pdo->prepare("SELECT id FROM shipments WHERE shipment_number = ?");
        $stmt->execute([$shipment_number]);
        if ($stmt->rowCount() > 0) {
            $shipment_number = 'SHP' . date('Ymd') . sprintf('%03d', rand(1, 999));
        }

        // 生成物流单号
        $tracking_number = '';
        if ($carrier_id) {
            // 获取物流公司信息
            $stmt = $pdo->prepare("SELECT name FROM carriers WHERE id = ?");
            $stmt->execute([$carrier_id]);
            $carrier = $stmt->fetch();

            if ($carrier) {
                // 根据物流公司和当前时间生成唯一的物流单号
                $carrier_prefix = strtoupper(mb_substr($carrier['name'], 0, 2)); // 取物流公司名称前两个字符作为前缀
                $tracking_number = $carrier_prefix . date('YmdHis') . rand(1000, 9999);
            }
        }

        // 插入发货单
        $stmt = $pdo->prepare("
            INSERT INTO shipments (
                shipment_number, 
                sales_order_id, 
                carrier_id, 
                tracking_number, 
                shipment_date, 
                estimated_delivery_date, 
                shipping_cost, 
                status, 
                notes
            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
        ");

        $stmt->execute([
            $shipment_number,
            $sales_order_id,
            $carrier_id,
            $tracking_number,
            $shipment_date,
            $estimated_delivery_date,
            $shipping_cost,
            $status,
            $notes
        ]);

        // 更新销售订单状态（如果需要）
        if ($status != 'pending') {
            $stmt = $pdo->prepare("
                UPDATE sales_orders 
                SET status = ? 
                WHERE id = ?
            ");
            $order_status = ($status == 'delivered') ? 'delivered' : 'shipped';
            $stmt->execute([$order_status, $sales_order_id]);
        }

        $success = "发货单创建成功！编号：" . $shipment_number;
    } catch (Exception $e) {
        $error = "添加失败: " . $e->getMessage();
    }
}

// 处理更新发货单请求
if (isset($_POST['update_shipment'])) {
    $id = (int)$_POST['id'];
    $carrier_id = !empty($_POST['carrier_id']) ? (int)$_POST['carrier_id'] : null;
    $tracking_number = trim($_POST['tracking_number']);
    $shipment_date = $_POST['shipment_date'];
    $estimated_delivery_date = !empty($_POST['estimated_delivery_date']) ? $_POST['estimated_delivery_date'] : null;
    $actual_delivery_date = !empty($_POST['actual_delivery_date']) ? $_POST['actual_delivery_date'] : null;
    $shipping_cost = !empty($_POST['shipping_cost']) ? $_POST['shipping_cost'] : null;
    $status = $_POST['status'];
    $notes = trim($_POST['notes']);

    try {
        // 更新发货单
        $stmt = $pdo->prepare("
            UPDATE shipments 
            SET carrier_id = ?, 
                tracking_number = ?, 
                shipment_date = ?, 
                estimated_delivery_date = ?, 
                actual_delivery_date = ?, 
                shipping_cost = ?, 
                status = ?, 
                notes = ?
            WHERE id = ?
        ");

        $stmt->execute([
            $carrier_id,
            $tracking_number,
            $shipment_date,
            $estimated_delivery_date,
            $actual_delivery_date,
            $shipping_cost,
            $status,
            $notes,
            $id
        ]);

        // 获取销售订单ID
        $stmt = $pdo->prepare("SELECT sales_order_id FROM shipments WHERE id = ?");
        $stmt->execute([$id]);
        $sales_order_id = $stmt->fetchColumn();

        // 更新销售订单状态（如果需要）
        if ($sales_order_id) {
            $stmt = $pdo->prepare("
                UPDATE sales_orders 
                SET status = ? 
                WHERE id = ?
            ");
            $order_status = ($status == 'delivered') ? 'delivered' : 'shipped';
            $stmt->execute([$order_status, $sales_order_id]);
        }

        $success = "发货单更新成功！";
    } catch (PDOException $e) {
        $error = "更新失败: " . $e->getMessage();
    }
}

// 获取所有物流公司
try {
    $stmt = $pdo->query("SELECT id, name FROM carriers WHERE is_active = 1 ORDER BY name");
    $carriers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取物流公司失败: " . $e->getMessage();
}

// 获取待发货订单
try {
    $stmt = $pdo->query("
        SELECT 
            so.id, 
            so.order_number, 
            so.order_date,
            c.name AS customer_name
        FROM 
            sales_orders so
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            so.status IN ('confirmed', 'processing', 'partially_shipped')
        ORDER BY 
            so.order_date DESC
        LIMIT 50
    ");
    $pending_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取待发货订单失败: " . $e->getMessage();
}

// 获取发货单列表
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$status_filter = isset($_GET['status']) ? $_GET['status'] : '';
$carrier_filter = isset($_GET['carrier_id']) ? (int)$_GET['carrier_id'] : 0;
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '';

try {
    $query = "
        SELECT 
            s.id,
            s.shipment_number,
            s.tracking_number,
            s.shipment_date,
            s.estimated_delivery_date,
            s.actual_delivery_date,
            s.shipping_cost,
            s.status,
            s.notes,
            so.order_number,
            c.name AS customer_name,
            cr.name AS carrier_name
        FROM 
            shipments s
        JOIN 
            sales_orders so ON s.sales_order_id = so.id
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        LEFT JOIN 
            carriers cr ON s.carrier_id = cr.id
        WHERE 1=1
    ";

    $params = [];

    if (!empty($search)) {
        $query .= " AND (s.shipment_number LIKE ? OR s.tracking_number LIKE ? OR so.order_number LIKE ?)";
        $params[] = "%{$search}%";
        $params[] = "%{$search}%";
        $params[] = "%{$search}%";
    }

    if (!empty($status_filter)) {
        $query .= " AND s.status = ?";
        $params[] = $status_filter;
    }

    if ($carrier_filter > 0) {
        $query .= " AND s.carrier_id = ?";
        $params[] = $carrier_filter;
    }

    if (!empty($date_from)) {
        $query .= " AND DATE(s.shipment_date) >= ?";
        $params[] = $date_from;
    }

    if (!empty($date_to)) {
        $query .= " AND DATE(s.shipment_date) <= ?";
        $params[] = $date_to;
    }

    $query .= " ORDER BY s.shipment_date DESC";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $shipments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "查询数据时出错: " . $e->getMessage();
}

// 状态映射
$status_map = [
    'pending' => '待处理',
    'ready_to_ship' => '待发货',
    'shipped' => '已发货',
    'in_transit' => '运输中',
    'delivered' => '已送达',
    'failed' => '发货失败',
    'cancelled' => '已取消'
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>发货单管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 模态框样式优化 */
        .modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgba(0, 0, 0, 0.4);
        }

        .modal-content {
            background-color: #fefefe;
            margin: 5% auto;
            padding: 20px;
            border: 1px solid #888;
            width: 80%;
            max-width: 600px;
            border-radius: 8px;
            max-height: 80vh;
            overflow-y: auto;
        }

        .close {
            color: #aaa;
            float: right;
            font-size: 28px;
            font-weight: bold;
            cursor: pointer;
        }

        .close:hover,
        .close:focus {
            color: black;
            text-decoration: none;
        }

        .modal-title {
            margin-top: 0;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        /* 状态标签样式 */
        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            color: white;
            white-space: nowrap;
        }

        /* 操作按钮容器 */
        .btn-container {
            display: flex;
            flex-direction: column;
            gap: 5px;
        }

        /* 操作按钮样式 */
        .btn-edit,
        .btn-track {
            display: block;
            padding: 6px 12px;
            text-align: center;
            border-radius: 4px;
            font-size: 13px;
            text-decoration: none;
            color: white;
            white-space: nowrap;
            min-width: 40px;
        }

        .btn-edit {
            background-color: #17a2b8;
        }

        .btn-track {
            background-color: #3498db;
        }

        .btn-edit:hover {
            background-color: #138496;
        }

        .btn-track:hover {
            background-color: #2980b9;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>发货单管理</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="text" name="search" placeholder="搜索发货单号/物流单号/订单号" value="<?= htmlspecialchars($search) ?>">

                <select name="status">
                    <option value="">所有状态</option>
                    <?php foreach ($status_map as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $status_filter === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="carrier_id">
                    <option value="0">所有物流公司</option>
                    <?php foreach ($carriers as $carrier): ?>
                        <option value="<?= $carrier['id'] ?>" <?= $carrier_filter === $carrier['id'] ? 'selected' : '' ?>><?= htmlspecialchars($carrier['name']) ?></option>
                    <?php endforeach; ?>
                </select>

                <input type="date" name="date_from" placeholder="起始日期" value="<?= htmlspecialchars($date_from) ?>">
                <input type="date" name="date_to" placeholder="结束日期" value="<?= htmlspecialchars($date_to) ?>">

                <button type="submit">筛选</button>
                <button type="button" onclick="location.href='shipment_management.php'" class="btn-cancel">重置</button>
            </form>

            <button class="btn-add" onclick="openAddModal()">创建发货单</button>
        </div>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>发货单号</th>
                        <th>订单号</th>
                        <th>客户</th>
                        <th>物流公司</th>
                        <th>物流单号</th>
                        <th>发货日期</th>
                        <th>预计送达</th>
                        <th>物流费用</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($shipments)): ?>
                        <tr>
                            <td colspan="10" class="text-center">暂无发货记录</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($shipments as $shipment): ?>
                            <tr>
                                <td><?= htmlspecialchars($shipment['shipment_number']) ?></td>
                                <td><?= htmlspecialchars($shipment['order_number']) ?></td>
                                <td><?= htmlspecialchars($shipment['customer_name']) ?></td>
                                <td><?= htmlspecialchars($shipment['carrier_name'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($shipment['tracking_number'] ?: '-') ?></td>
                                <td><?= date('Y-m-d', strtotime($shipment['shipment_date'])) ?></td>
                                <td><?= $shipment['estimated_delivery_date'] ? date('Y-m-d', strtotime($shipment['estimated_delivery_date'])) : '-' ?></td>
                                <td><?= $shipment['shipping_cost'] ? number_format($shipment['shipping_cost'], 2) : '-' ?></td>
                                <td>
                                    <span class="status-tag <?= $shipment['status'] ?>">
                                        <?= $status_map[$shipment['status']] ?? $shipment['status'] ?>
                                    </span>
                                </td>
                                <td>
                                    <div class="btn-container">
                                        <a href="javascript:void(0)" onclick="openEditModal(<?= $shipment['id'] ?>)" class="btn-edit">编辑</a>
                                        <?php if (in_array($shipment['status'], ['shipped', 'in_transit'])): ?>
                                            <a href="javascript:void(0)" onclick="trackShipment('<?= htmlspecialchars($shipment['tracking_number']) ?>', '<?= htmlspecialchars($shipment['carrier_name']) ?>')" class="btn-track">追踪</a>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- 创建发货单弹窗 -->
        <div id="addModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeModal('addModal')">&times;</span>
                <h3 class="modal-title">创建发货单</h3>
                <form method="POST" action="">
                    <div class="form-group">
                        <label>选择订单</label>
                        <select name="sales_order_id" required>
                            <option value="">-- 选择订单 --</option>
                            <?php foreach ($pending_orders as $order): ?>
                                <option value="<?= $order['id'] ?>"><?= htmlspecialchars($order['order_number']) ?> - <?= htmlspecialchars($order['customer_name']) ?> (<?= date('Y-m-d', strtotime($order['order_date'])) ?>)</option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>物流公司</label>
                        <select name="carrier_id">
                            <option value="">-- 选择物流公司 --</option>
                            <?php foreach ($carriers as $carrier): ?>
                                <option value="<?= $carrier['id'] ?>"><?= htmlspecialchars($carrier['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                        <small>注：选择物流公司后将自动生成物流单号</small>
                    </div>
                    <div class="form-group">
                        <label>发货日期</label>
                        <input type="datetime-local" name="shipment_date" value="<?= date('Y-m-d\TH:i') ?>" required>
                    </div>
                    <div class="form-group">
                        <label>预计送达日期</label>
                        <input type="date" name="estimated_delivery_date" value="<?= date('Y-m-d', strtotime('+3 days')) ?>">
                    </div>
                    <div class="form-group">
                        <label>物流费用</label>
                        <input type="number" name="shipping_cost" step="0.01" min="0" placeholder="物流费用">
                    </div>
                    <div class="form-group">
                        <label>状态</label>
                        <select name="status" required>
                            <option value="pending">待处理</option>
                            <option value="ready_to_ship">待发货</option>
                            <option value="shipped">已发货</option>
                            <option value="in_transit">运输中</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>备注</label>
                        <textarea name="notes" rows="3" placeholder="发货备注..."></textarea>
                    </div>
                    <button type="submit" name="add_shipment">创建发货单</button>
                </form>
            </div>
        </div>

        <!-- 编辑发货单弹窗 -->
        <div id="editModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeModal('editModal')">&times;</span>
                <h3 class="modal-title">编辑发货单</h3>
                <form method="POST" action="" id="editForm">
                    <input type="hidden" name="id" id="edit_id">
                    <div class="form-group">
                        <label>订单号</label>
                        <input type="text" id="edit_order_number" readonly>
                    </div>
                    <div class="form-group">
                        <label>发货单号</label>
                        <input type="text" id="edit_shipment_number" readonly>
                    </div>
                    <div class="form-group">
                        <label>物流公司</label>
                        <select name="carrier_id" id="edit_carrier_id">
                            <option value="">-- 选择物流公司 --</option>
                            <?php foreach ($carriers as $carrier): ?>
                                <option value="<?= $carrier['id'] ?>"><?= htmlspecialchars($carrier['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>物流单号</label>
                        <input type="text" name="tracking_number" id="edit_tracking_number" placeholder="输入物流单号">
                    </div>
                    <div class="form-group">
                        <label>发货日期</label>
                        <input type="datetime-local" name="shipment_date" id="edit_shipment_date" required>
                    </div>
                    <div class="form-group">
                        <label>预计送达日期</label>
                        <input type="date" name="estimated_delivery_date" id="edit_estimated_delivery_date">
                    </div>
                    <div class="form-group">
                        <label>实际送达日期</label>
                        <input type="datetime-local" name="actual_delivery_date" id="edit_actual_delivery_date">
                    </div>
                    <div class="form-group">
                        <label>物流费用</label>
                        <input type="number" name="shipping_cost" id="edit_shipping_cost" step="0.01" min="0">
                    </div>
                    <div class="form-group">
                        <label>状态</label>
                        <select name="status" id="edit_status" required>
                            <?php foreach ($status_map as $key => $value): ?>
                                <option value="<?= $key ?>"><?= $value ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>备注</label>
                        <textarea name="notes" id="edit_notes" rows="3"></textarea>
                    </div>
                    <button type="submit" name="update_shipment">保存更改</button>
                </form>
            </div>
        </div>

        <script>
            // 打开添加弹窗
            function openAddModal() {
                document.getElementById('addModal').style.display = 'block';
            }

            // 打开编辑弹窗
            function openEditModal(id) {
                // 通过AJAX获取发货单信息
                fetch('get_shipment.php?id=' + id)
                    .then(response => response.json())
                    .then(data => {
                        if (data.error) {
                            alert(data.error);
                            return;
                        }

                        // 填充表单
                        document.getElementById('edit_id').value = data.id;
                        document.getElementById('edit_order_number').value = data.order_number;
                        document.getElementById('edit_shipment_number').value = data.shipment_number;
                        document.getElementById('edit_carrier_id').value = data.carrier_id || '';
                        document.getElementById('edit_tracking_number').value = data.tracking_number || '';

                        // 日期时间处理
                        if (data.shipment_date) {
                            document.getElementById('edit_shipment_date').value = formatDateTime(data.shipment_date);
                        }
                        if (data.estimated_delivery_date) {
                            document.getElementById('edit_estimated_delivery_date').value = formatDate(data.estimated_delivery_date);
                        }
                        if (data.actual_delivery_date) {
                            document.getElementById('edit_actual_delivery_date').value = formatDateTime(data.actual_delivery_date);
                        }

                        document.getElementById('edit_shipping_cost').value = data.shipping_cost || '';
                        document.getElementById('edit_status').value = data.status;
                        document.getElementById('edit_notes').value = data.notes || '';

                        // 显示弹窗
                        document.getElementById('editModal').style.display = 'block';
                    })
                    .catch(error => {
                        console.error('Error:', error);
                        alert('获取数据失败，请重试');
                    });
            }

            // 格式化日期时间
            function formatDateTime(dateString) {
                const date = new Date(dateString);
                return date.getFullYear() +
                    '-' + String(date.getMonth() + 1).padStart(2, '0') +
                    '-' + String(date.getDate()).padStart(2, '0') +
                    'T' + String(date.getHours()).padStart(2, '0') +
                    ':' + String(date.getMinutes()).padStart(2, '0');
            }

            // 格式化日期
            function formatDate(dateString) {
                const date = new Date(dateString);
                return date.getFullYear() +
                    '-' + String(date.getMonth() + 1).padStart(2, '0') +
                    '-' + String(date.getDate()).padStart(2, '0');
            }

            // 关闭弹窗
            function closeModal(modalId) {
                document.getElementById(modalId).style.display = 'none';
            }

            // 物流追踪
            function trackShipment(trackingNumber, carrierName) {
                if (!trackingNumber) {
                    alert('没有物流单号，无法追踪');
                    return;
                }

                window.location.href = 'shipment_tracking.php?tracking_number=' + encodeURIComponent(trackingNumber) + '&carrier=' + encodeURIComponent(carrierName);
            }

            // 点击弹窗外部关闭
            window.onclick = function(event) {
                if (event.target.className === 'modal') {
                    event.target.style.display = 'none';
                }
            }
        </script>
    </div>
</body>

</html>