<?php
// 开始会话
session_start();

// 检查用户是否登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

require_once '../config.php';

// 初始化变量
$error = '';
$success = '';
$order_types = ['online' => '线上订单', 'offline' => '线下订单', 'wholesale' => '批发订单', 'ecommerce' => '电商平台订单'];
$payment_statuses = ['pending' => '待付款', 'paid' => '已付款', 'partially_paid' => '部分付款', 'refunded' => '已退款'];
$order_statuses = ['draft' => '草稿', 'confirmed' => '已确认', 'processing' => '处理中', 'partially_shipped' => '部分发货', 'shipped' => '已发货', 'delivered' => '已送达', 'cancelled' => '已取消'];

// 检查数据库表是否存在
try {
    // 检查sales_orders表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'sales_orders'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("订单表不存在，请先访问订单列表页面创建表结构");
    }

    // 检查sales_order_items表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'sales_order_items'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("订单项表不存在，请先访问订单列表页面创建表结构");
    }

    // 检查sales_channels表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'sales_channels'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("销售渠道表不存在，请先访问订单列表页面创建表结构");
    }

    // 检查customers表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'customers'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("客户表不存在，请先访问订单列表页面创建表结构");
    }

    // 检查products表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'products'");
    if ($stmt->rowCount() == 0) {
        throw new Exception("产品表不存在，请先创建产品");
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}

// 处理表单提交
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['create_order'])) {
    try {
        // 开启事务
        $pdo->beginTransaction();

        // 准备订单数据
        $order_number = 'ORD' . date('YmdHis') . rand(100, 999);
        $order_date = date('Y-m-d H:i:s');
        $customer_id = $_POST['customer_id'];
        $sales_channel_id = $_POST['sales_channel_id'];
        $order_type = $_POST['order_type'];
        $status = $_POST['status'];
        $shipping_address = $_POST['shipping_address'] ?? null;
        $notes = $_POST['notes'] ?? null;
        $required_date = $_POST['required_date'] ?? null;
        $total_amount = 0; // 初始化总金额，会在添加订单项时计算

        // 插入订单主表
        $stmt = $pdo->prepare("
            INSERT INTO sales_orders 
            (order_number, order_date, customer_id, sales_channel_id, status, total_amount, 
             shipping_address, notes, required_date, created_by_user_id) 
            VALUES 
            (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $order_number,
            $order_date,
            $customer_id,
            $sales_channel_id,
            $status,
            $total_amount,
            $shipping_address,
            $notes,
            $required_date,
            $_SESSION['user_id']
        ]);

        $sales_order_id = $pdo->lastInsertId();

        // 处理订单项
        if (isset($_POST['product_id']) && is_array($_POST['product_id'])) {
            for ($i = 0; $i < count($_POST['product_id']); $i++) {
                if (empty($_POST['product_id'][$i])) {
                    continue; // 跳过空项
                }

                $product_id = $_POST['product_id'][$i];
                $quantity = $_POST['quantity'][$i];
                $unit_price = $_POST['unit_price'][$i];
                $discount_rate = isset($_POST['discount_rate'][$i]) ? $_POST['discount_rate'][$i] : 0;
                $item_total = $quantity * $unit_price * (1 - $discount_rate);

                // 累加总金额
                $total_amount += $item_total;

                // 插入订单项
                $stmt = $pdo->prepare("
                    INSERT INTO sales_order_items 
                    (sales_order_id, product_id, quantity, unit_price, discount_rate) 
                    VALUES 
                    (?, ?, ?, ?, ?)
                ");
                $stmt->execute([$sales_order_id, $product_id, $quantity, $unit_price, $discount_rate]);
            }

            // 更新订单总金额
            $stmt = $pdo->prepare("UPDATE sales_orders SET total_amount = ? WHERE id = ?");
            $stmt->execute([$total_amount, $sales_order_id]);
        }

        // 提交事务
        $pdo->commit();

        $success = "订单创建成功！订单号: " . $order_number;

        // 重定向到订单列表页面
        header("Location: order_list.php?success=" . urlencode($success));
        exit;
    } catch (PDOException $e) {
        // 回滚事务
        $pdo->rollBack();
        $error = "创建订单失败: " . $e->getMessage();

        if (isset($_SESSION['role_id']) && $_SESSION['role_id'] == 1) {
            $error .= "<br>SQL错误详情: " . $e->getMessage();
        }
    }
}

// 获取客户列表
try {
    $stmt = $pdo->query("SELECT id, name, type FROM customers ORDER BY name");
    $customers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error .= "<br>获取客户列表失败: " . $e->getMessage();
    $customers = [];
}

// 获取销售渠道列表
try {
    $stmt = $pdo->query("SELECT id, name FROM sales_channels ORDER BY name");
    $sales_channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error .= "<br>获取销售渠道列表失败: " . $e->getMessage();
    $sales_channels = [];
}

// 获取产品列表
try {
    $stmt = $pdo->query("SHOW COLUMNS FROM products");
    $product_columns = $stmt->fetchAll(PDO::FETCH_COLUMN);

    $select_fields = ["id", "name"];

    $unit_field = in_array("unit", $product_columns) ? "unit" : "'件' AS unit";
    $select_fields[] = $unit_field;

    if (in_array("price", $product_columns)) {
        $select_fields[] = "price";
    } elseif (in_array("unit_price", $product_columns)) {
        $select_fields[] = "unit_price AS price";
    } elseif (in_array("sales_price", $product_columns)) {
        $select_fields[] = "sales_price AS price";
    } elseif (in_array("retail_price", $product_columns)) {
        $select_fields[] = "retail_price AS price";
    } else {
        $select_fields[] = "0 AS price";
    }

    $where_clause = "";
    if (in_array("status", $product_columns)) {
        $where_clause = " WHERE status = 'active'";
    }

    $query = "SELECT " . implode(", ", $select_fields) . " FROM products" . $where_clause . " ORDER BY name";
    $stmt = $pdo->query($query);
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error .= "<br>获取产品列表失败: " . $e->getMessage();
    $products = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>创建销售订单 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-control {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 14px;
            box-sizing: border-box;
        }

        /* 商品表格样式 */
        .table-responsive {
            overflow-x: auto;
        }

        .table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 1rem;
        }

        .table th,
        .table td {
            padding: 12px;
            vertical-align: top;
            border-top: 1px solid #dee2e6;
        }

        .table thead th {
            vertical-align: bottom;
            border-bottom: 2px solid #dee2e6;
            background-color: #f8f9fa;
        }

        .table-bordered {
            border: 1px solid #dee2e6;
        }

        .table-bordered th,
        .table-bordered td {
            border: 1px solid #dee2e6;
        }

        /* 按钮样式 */
        .btn {
            display: inline-block;
            font-weight: 400;
            text-align: center;
            white-space: nowrap;
            vertical-align: middle;
            user-select: none;
            border: 1px solid transparent;
            padding: 0.375rem 0.75rem;
            font-size: 1rem;
            line-height: 1.5;
            border-radius: 0.25rem;
            transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
            cursor: pointer;
        }

        .btn-primary {
            color: #fff;
            background-color: #3498db;
            border-color: #3498db;
        }

        .btn-secondary {
            color: #fff;
            background-color: #6c757d;
            border-color: #6c757d;
        }

        .btn-danger {
            color: #fff;
            background-color: #dc3545;
            border-color: #dc3545;
        }

        .btn-sm {
            padding: 0.25rem 0.5rem;
            font-size: 0.875rem;
            line-height: 1.5;
            border-radius: 0.2rem;
        }

        /* 卡片样式 */
        .card {
            position: relative;
            display: flex;
            flex-direction: column;
            min-width: 0;
            word-wrap: break-word;
            background-color: #fff;
            background-clip: border-box;
            border: 1px solid rgba(0, 0, 0, 0.125);
            border-radius: 0.25rem;
            margin-bottom: 1rem;
        }

        .card-header {
            padding: 0.75rem 1.25rem;
            margin-bottom: 0;
            background-color: rgba(0, 0, 0, 0.03);
            border-bottom: 1px solid rgba(0, 0, 0, 0.125);
        }

        .card-header h5 {
            margin: 0;
            font-size: 1.25rem;
        }

        .card-body {
            flex: 1 1 auto;
            padding: 1.25rem;
        }

        /* 网格布局 */
        .row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -15px;
            margin-left: -15px;
        }

        .col-md-4,
        .col-md-6 {
            position: relative;
            width: 100%;
            padding-right: 15px;
            padding-left: 15px;
        }

        .col-md-4 {
            flex: 0 0 33.333333%;
            max-width: 33.333333%;
        }

        .col-md-6 {
            flex: 0 0 50%;
            max-width: 50%;
        }

        /* 提醒样式 */
        .alert {
            position: relative;
            padding: 0.75rem 1.25rem;
            margin-bottom: 1rem;
            border: 1px solid transparent;
            border-radius: 0.25rem;
        }

        .alert-danger {
            color: #721c24;
            background-color: #f8d7da;
            border-color: #f5c6cb;
        }

        .alert-success {
            color: #155724;
            background-color: #d4edda;
            border-color: #c3e6cb;
        }

        /* 文本对齐 */
        .text-right {
            text-align: right;
        }

        .text-center {
            text-align: center;
        }
    </style>
</head>

<body>

    <div class="content">
        <h1>创建销售订单</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <div class="section">
            <form method="post" action="" class="order-form">
                <div class="card">
                    <div class="card-header">
                        <h5>订单基本信息</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="customer_id">客户</label>
                                    <select name="customer_id" id="customer_id" class="form-control" required>
                                        <option value="">-- 请选择客户 --</option>
                                        <?php foreach ($customers as $customer): ?>
                                            <option value="<?= $customer['id'] ?>">
                                                <?= htmlspecialchars($customer['name']) ?>
                                                (<?= $customer['type'] == 'individual' ? '个人' : ($customer['type'] == 'company' ? '公司' : '经销商') ?>)
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="sales_channel_id">销售渠道</label>
                                    <select name="sales_channel_id" id="sales_channel_id" class="form-control" required>
                                        <option value="">-- 请选择销售渠道 --</option>
                                        <?php foreach ($sales_channels as $channel): ?>
                                            <option value="<?= $channel['id'] ?>"><?= htmlspecialchars($channel['name']) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label for="order_type">订单类型</label>
                                    <select name="order_type" id="order_type" class="form-control" required>
                                        <?php foreach ($order_types as $key => $value): ?>
                                            <option value="<?= $key ?>"><?= $value ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label for="status">订单状态</label>
                                    <select name="status" id="status" class="form-control" required>
                                        <?php foreach ($order_statuses as $key => $value): ?>
                                            <option value="<?= $key ?>"><?= $value ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label for="payment_status">支付状态</label>
                                    <select name="payment_status" id="payment_status" class="form-control" required>
                                        <?php foreach ($payment_statuses as $key => $value): ?>
                                            <option value="<?= $key ?>"><?= $value ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header" style="display: flex; justify-content: space-between; align-items: center;">
                        <h5>订单商品</h5>
                        <button type="button" class="btn btn-primary btn-sm" id="add-product">添加商品</button>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered" id="products-table">
                                <thead>
                                    <tr>
                                        <th>商品名称</th>
                                        <th>单价(元)</th>
                                        <th>数量</th>
                                        <th>单位</th>
                                        <th>小计(元)</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <!-- 初始化第一个产品行 -->
                                    <tr class="product-row">
                                        <td>
                                            <select name="product_id[]" class="form-control product-select" required>
                                                <option value="">-- 选择商品 --</option>
                                                <?php foreach ($products as $product): ?>
                                                    <option value="<?= $product['id'] ?>" data-price="<?= $product['price'] ?>" data-unit="<?= $product['unit'] ?>">
                                                        <?= htmlspecialchars($product['name']) ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                        <td>
                                            <input type="number" name="unit_price[]" class="form-control unit-price" step="0.01" min="0" required>
                                        </td>
                                        <td>
                                            <input type="number" name="quantity[]" class="form-control quantity" min="1" value="1" required>
                                        </td>
                                        <td class="product-unit"></td>
                                        <td class="subtotal">0.00</td>
                                        <td>
                                            <button type="button" class="btn btn-danger btn-sm remove-product">删除</button>
                                        </td>
                                    </tr>
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <td colspan="4" class="text-right"><strong>总计</strong></td>
                                        <td id="total-amount">0.00</td>
                                        <td></td>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>
                    </div>
                </div>

                <div class="form-group text-center" style="margin-top: 20px;">
                    <button type="submit" name="create_order" class="btn btn-primary">创建订单</button>
                    <a href="order_list.php" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    </div>

    <script>
        // 添加商品行
        document.getElementById('add-product').addEventListener('click', function() {
            const tbody = document.querySelector('#products-table tbody');
            const firstRow = document.querySelector('.product-row');
            const newRow = firstRow.cloneNode(true);

            // 清空新行的输入值
            newRow.querySelectorAll('input').forEach(input => input.value = '');
            newRow.querySelector('select').selectedIndex = 0;
            newRow.querySelector('.subtotal').textContent = '0.00';
            newRow.querySelector('.product-unit').textContent = '';

            tbody.appendChild(newRow);
            updateTotalAmount();
        });

        // 删除商品行
        document.addEventListener('click', function(e) {
            if (e.target.classList.contains('remove-product')) {
                const rows = document.querySelectorAll('.product-row');
                if (rows.length > 1) {
                    e.target.closest('tr').remove();
                    updateTotalAmount();
                } else {
                    alert('至少需要一个商品项');
                }
            }
        });

        // 商品选择变化时，更新单价和单位
        document.addEventListener('change', function(e) {
            if (e.target.classList.contains('product-select')) {
                const selected = e.target.options[e.target.selectedIndex];
                const price = selected.dataset.price;
                const unit = selected.dataset.unit;
                const row = e.target.closest('tr');

                row.querySelector('.unit-price').value = price;
                row.querySelector('.product-unit').textContent = unit;

                updateSubtotal(row);
            }
        });

        // 数量或单价变化时，更新小计
        document.addEventListener('input', function(e) {
            if (e.target.classList.contains('quantity') || e.target.classList.contains('unit-price')) {
                updateSubtotal(e.target.closest('tr'));
            }
        });

        // 更新某一行的小计
        function updateSubtotal(row) {
            const quantity = parseFloat(row.querySelector('.quantity').value) || 0;
            const unitPrice = parseFloat(row.querySelector('.unit-price').value) || 0;
            const subtotal = quantity * unitPrice;
            row.querySelector('.subtotal').textContent = subtotal.toFixed(2);

            updateTotalAmount();
        }

        // 更新总金额
        function updateTotalAmount() {
            let total = 0;
            document.querySelectorAll('.subtotal').forEach(function(el) {
                total += parseFloat(el.textContent) || 0;
            });
            document.getElementById('total-amount').textContent = total.toFixed(2);
        }
    </script>
</body>

</html>