<?php
session_start();
require_once '../config.php';

// 检查用户是否登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';
$channels = [];
$edit_id = 0;
$edit_data = [
    'name' => '',
    'description' => '',
    'is_active' => 1
];

// 检查sales_channels表是否存在,不存在则创建
try {
    $stmt = $pdo->query("SHOW TABLES LIKE 'sales_channels'");
    if ($stmt->rowCount() == 0) {
        // 表不存在,创建表
        $pdo->exec("
            -- 创建销售渠道表
            CREATE TABLE `sales_channels` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '渠道ID',
              `name` VARCHAR(50) NOT NULL COMMENT '渠道名称 (例如: B2B批发, 电商平台, 线下经销)',
              `description` VARCHAR(255) DEFAULT NULL COMMENT '渠道描述',
              `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否启用',
              PRIMARY KEY (`id`),
              UNIQUE KEY `uk_channel_name` (`name`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='销售渠道信息表'
        ");

        // 插入默认数据
        $pdo->exec("
            INSERT INTO `sales_channels` (`name`, `description`, `is_active`)
            VALUES 
            ('B2B批发', '面向批发客户的渠道', 1),
            ('电商平台', '如淘宝、京东等线上销售渠道', 1),
            ('线下经销', '通过各地经销商销售', 1),
            ('零售直营', '公司直接零售', 1)
        ");

        $success = "销售渠道表已创建并添加默认数据";
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败: " . $e->getMessage();
}

// 处理添加渠道
if (isset($_POST['add_channel'])) {
    $name = trim($_POST['name']);
    $description = trim($_POST['description']);
    $is_active = isset($_POST['is_active']) ? 1 : 0;

    if (empty($name)) {
        $error = "渠道名称不能为空";
    } else {
        try {
            $stmt = $pdo->prepare("
                INSERT INTO sales_channels (name, description, is_active) 
                VALUES (?, ?, ?)
            ");
            $stmt->execute([$name, $description, $is_active]);
            $success = "销售渠道添加成功";
        } catch (PDOException $e) {
            if ($e->getCode() == 23000) { // 唯一键约束冲突
                $error = "渠道名称已存在,请使用其他名称";
            } else {
                $error = "添加渠道失败: " . $e->getMessage();
            }
        }
    }
}

// 处理更新渠道
if (isset($_POST['update_channel'])) {
    $id = (int)$_POST['id'];
    $name = trim($_POST['name']);
    $description = trim($_POST['description']);
    $is_active = isset($_POST['is_active']) ? 1 : 0;

    if (empty($name)) {
        $error = "渠道名称不能为空";
    } else {
        try {
            $stmt = $pdo->prepare("
                UPDATE sales_channels 
                SET name = ?, description = ?, is_active = ?
                WHERE id = ?
            ");
            $stmt->execute([$name, $description, $is_active, $id]);
            $success = "销售渠道更新成功";
        } catch (PDOException $e) {
            if ($e->getCode() == 23000) { // 唯一键约束冲突
                $error = "渠道名称已存在,请使用其他名称";
            } else {
                $error = "更新渠道失败: " . $e->getMessage();
            }
        }
    }
}

// 读取编辑数据
if (isset($_GET['edit']) && !empty($_GET['edit'])) {
    $edit_id = (int)$_GET['edit'];

    // 不允许编辑系统预置的渠道(ID<=4)
    if ($edit_id <= 4) {
        $error = "系统预置渠道不允许编辑";
        $edit_id = 0;
    } else {
        try {
            $stmt = $pdo->prepare("SELECT * FROM sales_channels WHERE id = ?");
            $stmt->execute([$edit_id]);
            $channel = $stmt->fetch();

            if ($channel) {
                $edit_data = $channel;
            } else {
                $error = "未找到要编辑的渠道";
                $edit_id = 0;
            }
        } catch (PDOException $e) {
            $error = "获取渠道数据失败: " . $e->getMessage();
        }
    }
}

// 获取所有渠道
try {
    $stmt = $pdo->query("
        SELECT c.*, 
               (SELECT COUNT(*) FROM sales_orders WHERE sales_channel_id = c.id) as order_count
        FROM sales_channels c
        ORDER BY c.is_active DESC, c.name
    ");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取渠道列表失败: " . $e->getMessage();
}

// 处理删除渠道
if (isset($_GET['delete']) && !empty($_GET['delete'])) {
    $id = (int)$_GET['delete'];

    // 不允许删除系统预置的渠道(ID<=4)
    if ($id <= 4) {
        $error = "系统预置渠道不允许删除";
    } else {
        try {
            // 检查是否有订单使用该渠道
            $stmt = $pdo->prepare("
                SELECT COUNT(*) as count 
                FROM sales_orders 
                WHERE sales_channel_id = ?
            ");
            $stmt->execute([$id]);
            $result = $stmt->fetch();

            if ($result['count'] > 0) {
                $error = "该渠道已被订单使用,无法删除";
            } else {
                $stmt = $pdo->prepare("DELETE FROM sales_channels WHERE id = ?");
                $stmt->execute([$id]);
                $success = "销售渠道删除成功";
            }
        } catch (PDOException $e) {
            $error = "删除渠道失败: " . $e->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售渠道管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="text"],
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group textarea:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        .form-group textarea {
            resize: vertical;
            min-height: 80px;
        }

        .form-group .checkbox-label {
            display: flex;
            align-items: center;
            font-weight: normal;
        }

        .form-group .checkbox-label input[type="checkbox"] {
            margin-right: 8px;
        }

        button,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            transition: background 0.3s;
        }

        button:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        /* 表格样式 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        /* 状态标签 */
        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            text-align: center;
        }

        .status-active {
            background-color: #28a745;
            color: white;
        }

        .status-inactive {
            background-color: #dc3545;
            color: white;
        }

        /* 操作按钮 */
        .btn-link {
            text-decoration: none;
            margin-right: 5px;
        }

        .btn-edit,
        .btn-delete {
            display: inline-block !important;
            padding: 4px 8px !important;
            border-radius: 4px !important;
            color: white !important;
            text-decoration: none !important;
            margin: 2px !important;
            font-weight: normal !important;
        }

        .btn-edit {
            background: #17a2b8 !important;
        }

        .btn-delete {
            background: #dc3545 !important;
        }

        .text-muted {
            color: #6c757d !important;
        }

        /* 消息样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 空状态样式 */
        .empty-state {
            text-align: center;
            padding: 40px 20px;
            background: #f8f9fa;
            border-radius: 8px;
            border: 1px dashed #ddd;
            color: #6c757d;
        }

        .empty-state p {
            margin: 0;
            font-size: 16px;
        }

        /* 表单布局 */
        .form-row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -10px;
            margin-left: -10px;
        }

        .form-col {
            flex: 1;
            padding: 0 10px;
            min-width: 200px;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>销售渠道管理</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <div class="section">
            <h2><?= $edit_id ? '编辑销售渠道' : '添加销售渠道' ?></h2>
            <form method="POST" action="">
                <?php if ($edit_id): ?>
                    <input type="hidden" name="id" value="<?= $edit_id ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-col">
                        <div class="form-group">
                            <label for="name">渠道名称</label>
                            <input type="text" id="name" name="name" value="<?= htmlspecialchars($edit_data['name']) ?>" required>
                        </div>
                    </div>
                    <div class="form-col">
                        <div class="form-group">
                            <label class="checkbox-label">
                                <input type="checkbox" name="is_active" <?= $edit_data['is_active'] ? 'checked' : '' ?>>
                                启用此渠道
                            </label>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <label for="description">渠道描述</label>
                    <textarea id="description" name="description" rows="3"><?= htmlspecialchars($edit_data['description']) ?></textarea>
                </div>

                <div style="margin-top: 20px;">
                    <button type="submit" name="<?= $edit_id ? 'update_channel' : 'add_channel' ?>" class="btn-primary">
                        <?= $edit_id ? '更新渠道' : '添加渠道' ?>
                    </button>
                    <?php if ($edit_id): ?>
                        <a href="sales_channels.php" class="btn-link" style="margin-left: 10px;">取消编辑</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>

        <div class="section">
            <h2>渠道列表</h2>
            <div class="table-container">
                <?php if (empty($channels)): ?>
                    <div class="empty-state">
                        <p>暂无销售渠道数据</p>
                    </div>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>渠道名称</th>
                                <th>描述</th>
                                <th>状态</th>
                                <th>关联订单数</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($channels as $channel): ?>
                                <tr>
                                    <td><?= $channel['id'] ?></td>
                                    <td><?= htmlspecialchars($channel['name']) ?></td>
                                    <td><?= htmlspecialchars($channel['description'] ?: '-') ?></td>
                                    <td>
                                        <span class="status-tag <?= $channel['is_active'] ? 'status-active' : 'status-inactive' ?>">
                                            <?= $channel['is_active'] ? '启用中' : '已禁用' ?>
                                        </span>
                                    </td>
                                    <td><?= $channel['order_count'] ?></td>
                                    <td>
                                        <?php if ($channel['id'] > 4): ?>
                                            <!-- 只有ID>4的渠道才显示编辑和删除按钮 -->
                                            <a href="sales_channels.php?edit=<?= $channel['id'] ?>" class="btn-edit">编辑</a>
                                            <?php if ($channel['order_count'] == 0): ?>
                                                <a href="sales_channels.php?delete=<?= $channel['id'] ?>" class="btn-delete" onclick="return confirm('确定要删除此渠道吗?')">删除</a>
                                            <?php endif; ?>
                                        <?php else: ?>
                                            <span class="text-muted">系统渠道</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <div class="section">
            <h2>渠道说明</h2>
            <p>销售渠道是公司销售产品的各种途径,包括但不限于:</p>
            <ul>
                <li><strong>B2B批发</strong> - 面向企业客户的大宗批发业务</li>
                <li><strong>电商平台</strong> - 通过电子商务平台进行的销售,如天猫、京东、拼多多等</li>
                <li><strong>线下经销商</strong> - 通过分布在各地的经销商进行销售</li>
                <li><strong>零售直营</strong> - 公司直接面向消费者的零售业务</li>
            </ul>
            <p>通过合理管理销售渠道,可以优化销售策略,提高产品覆盖率和销售业绩。</p>
        </div>
    </div>

    <script>
        // 可以在这里添加一些前端交互逻辑,如表单验证等
        document.addEventListener('DOMContentLoaded', function() {
            const nameInput = document.getElementById('name');
            if (nameInput) {
                nameInput.focus();
            }
        });
    </script>
</body>

</html>