<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// CSRF验证 - 由于是GET请求，这里不验证CSRF令牌
// 但未来可以考虑改为POST请求并添加CSRF验证

// 获取订单ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    $_SESSION['error'] = "无效的订单ID";
    header("Location: purchase_orders.php");
    exit;
}

$order_id = (int)$_GET['id'];

try {
    // 获取订单信息
    $stmt = $pdo->prepare("
        SELECT id, order_number, status, supplier_id 
        FROM purchase_orders 
        WHERE id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        throw new Exception("找不到指定订单");
    }

    // 验证订单状态是否为已审批
    if ($order['status'] !== 'approved') {
        throw new Exception("只有已审批的订单才能标记为已下单");
    }

    // 开始事务
    $pdo->beginTransaction();

    // 更新订单状态为已下单 - 移除ordered_at字段，因为数据库中不存在该字段
    $stmt = $pdo->prepare("
        UPDATE purchase_orders 
        SET status = 'ordered'
        WHERE id = ?
    ");
    $stmt->execute([$order_id]);

    // 记录操作日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '确认下单',
        'purchase_order',
        $order_id,
        json_encode([
            'order_number' => $order['order_number'],
            'status_change' => 'approved → ordered'
        ]),
        $_SERVER['REMOTE_ADDR']
    ]);

    // 提交事务
    $pdo->commit();

    $_SESSION['success'] = "订单 {$order['order_number']} 已成功标记为已下单";
} catch (Exception $e) {
    // 回滚事务
    if ($pdo->inTransaction()) {
        $pdo->rollBack();
    }
    $_SESSION['error'] = $e->getMessage();
}

// 重定向回采购订单列表
header("Location: purchase_orders.php");
exit;
